@@ -33,9 +33,10 @@
 #  define KGAPIMAPS_DEPRECATED_NO_EXPORT KGAPIMAPS_NO_EXPORT KGAPIMAPS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KGAPIMAPS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KGAPIMAPS_NO_DEPRECATED
+#    define KGAPIMAPS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
